@@ -29,13 +29,22 @@
 
 #include "light.data"
 
+// define static members
+QPixmap Light::lightPixmapS, Light::lightMaskS;  
+QPixmap Light::lightPixmapL, Light::lightMaskL;
+
 Light::Light(const QColor &cOn, const QColor &cOff, QWidget *parent, const char *name)
   : QLabel(parent, name),
+    lightStatus(false), bigLights(false),
     colorOn(cOn), colorOff(cOff)
     
 {
-  lightPixmap.loadFromData(light_9, light_9_size);
-  lightMask.loadFromData(light_mask_9, light_mask_9_size);
+  if(lightPixmapS.isNull()) {
+    lightPixmapS.loadFromData(light_9, light_9_size);
+    lightMaskS.loadFromData(light_mask_9, light_mask_9_size);
+    lightPixmapL.loadFromData(light_12, light_12_size);
+    lightMaskL.loadFromData(light_mask_12, light_mask_12_size);
+  }
 
   generateIcon(on, colorOn);
   generateIcon(off, colorOff);
@@ -43,16 +52,16 @@ Light::Light(const QColor &cOn, const QColor &cOff, QWidget *parent, const char
   setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum));
 
   setPixmap(off);
-  _status = false;
 }
 
 void Light::setStatus(bool s)
 {
-  if (s == _status)
+  if (s == lightStatus)
     return;
 
   setPixmap( s ? on : off);
-  _status = s;
+  lightStatus = s;
+  update();
 }
 
 void Light::setColors(const QColor &cOn, const QColor &cOff)
@@ -60,23 +69,39 @@ void Light::setColors(const QColor &cOn, const QColor &cOff)
   if (colorOn != cOn) {
     colorOn = cOn;
     generateIcon(on, colorOn);
-    if (_status)
+    if (lightStatus) {
       setPixmap(on);
+      update();
+    }
   }
   if (colorOff != cOff) {
     colorOff = cOff;
     generateIcon(off, colorOff);
-    if (!_status)
+    if (!lightStatus) {
       setPixmap(off);
+      update();
+    }
   }
 }
 
+void Light::setBig(bool b)
+{
+  if (b == bigLights)
+    return;
+
+  bigLights = b;
+  generateIcon(on, colorOn);
+  generateIcon(off, colorOff);
+  setPixmap(lightStatus ? on : off);
+  update();
+}
+
 void Light::generateIcon(QPixmap &px, QColor &col)
 {
-  px = lightMask;
+  px = bigLights ? lightMaskL : lightMaskS;
   QPainter p(&px);
   p.fillRect(0, 0, on.width()-1, on.height()-1, col);
-  p.drawPixmap(0, 0, lightPixmap);
+  p.drawPixmap(0, 0, bigLights ? lightPixmapL : lightPixmapS);
   p.end();
 }
 
