@@ -44,15 +44,13 @@ class StatusButton : public QPushButton
 
  private:
 
-  void generateIconOn();
-  void generateIconWait();
+  void generateIcon(QPixmap &px, QPixmap &sign, QColor &col);
 
   QPixmap on, off, wait;
   QPixmap signOn, signOff, signWait, signMask;
   QColor colorOn, colorWait;
 
   enum Status myStatus;
-
 };
 
 #endif
